Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5686)

Unified Diff: chrome/renderer/autofill/autofill_agent.h

Issue 7514003: Show display warning if the form is autocomplete off. (Closed) Base URL: http://git.chromium.org/git/chromium.git@trunk
Patch Set: Change autofill_query_node_ to autofill_query_element_ Created 9 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/renderer/autofill/autofill_agent.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/renderer/autofill/autofill_agent.h
diff --git a/chrome/renderer/autofill/autofill_agent.h b/chrome/renderer/autofill/autofill_agent.h
index d26b96f0102432cbf6cb43546049105a0af341b0..c2eec68a40c7f13a23c8a3be2af365e5c934e3c2 100644
--- a/chrome/renderer/autofill/autofill_agent.h
+++ b/chrome/renderer/autofill/autofill_agent.h
@@ -16,6 +16,7 @@
#include "content/renderer/render_view_observer.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebAutofillClient.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebNode.h"
+#include "third_party/WebKit/Source/WebKit/chromium/public/WebInputElement.h"
#include "webkit/glue/form_data.h"
#include "webkit/glue/form_field.h"
@@ -117,8 +118,8 @@ class AutofillAgent : public RenderViewObserver,
bool display_warning_if_disabled);
// Queries the browser for Autocomplete and Autofill suggestions for the given
- // |node|.
- void QueryAutofillSuggestions(const WebKit::WebNode& node,
+ // |element|.
+ void QueryAutofillSuggestions(const WebKit::WebInputElement& element,
bool display_warning_if_disabled);
// Queries the AutofillManager for form data for the form containing |node|.
@@ -144,8 +145,8 @@ class AutofillAgent : public RenderViewObserver,
// out of date responses.
int autofill_query_id_;
- // The node corresponding to the last request sent for form field Autofill.
- WebKit::WebNode autofill_query_node_;
+ // The element corresponding to the last request sent for form field Autofill.
+ WebKit::WebInputElement autofill_query_element_;
// The action to take when receiving Autofill data from the AutofillManager.
AutofillAction autofill_action_;
« no previous file with comments | « no previous file | chrome/renderer/autofill/autofill_agent.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698